PragmaName

Enum PragmaName 

pub enum PragmaName {
    AutoVacuum,
    CacheSize,
    ForeignKeyList,
    IntegrityCheck,
    JournalMode,
    LegacyFileFormat,
    PageCount,
    PageSize,
    SchemaVersion,
    TableInfo,
    UserVersion,
    WalCheckpoint,
}
PRAGMA value

Variants



AutoVacuum

set the autovacuum mode



CacheSize

cache_size pragma



ForeignKeyList

returns foreign key constraint information for a table



IntegrityCheck

Run integrity check on the database file



JournalMode

journal_mode pragma



LegacyFileFormat

Noop as per SQLite docs



PageCount

Return the total number of pages in the database file.



PageSize

Return the page size of the database in bytes.



SchemaVersion

Returns schema version of the database file.



TableInfo

returns information about the columns of a table



UserVersion

Returns the user version of the database file.



WalCheckpoint

trigger a checkpoint to run on database(s) if WAL is enabled